@@ -49,7 +49,7 @@ def generate_pymol(xyz_directory):
     os.chdir(xyz_folder_path)
     print("Directory Changed")
     # subprocess.Popen("mGenerate_PyMOL_Session.sh", cwd=None, shell= True)
-    subprocess.Popen("omolab_conf_analysis-0.1.5/mGenerate_PyMOL_Session.sh", cwd=None, shell= True)
+    subprocess.Popen("../scripts-3.8/mGenerate_PyMOL_Session.sh", cwd=None, shell= True)
 
 
 # testing function
